@@ -76,8 +76,8 @@ class CreateLease(command.CreateCommand):
     resource = 'lease'
     json_indent = 4
     log = logging.getLogger(__name__ + '.CreateLease')
-    default_start = datetime.datetime.utcnow()
-    default_end = default_start + datetime.timedelta(days=1)
+    default_start = 'now'
+    default_end = datetime.datetime.utcnow() + datetime.timedelta(days=1)
 
     def get_parser(self, prog_name):
         parser = super(CreateLease, self).get_parser(prog_name)
@@ -89,14 +89,14 @@ class CreateLease(command.CreateCommand):
             '--start-date',
             dest='start',
             help='Time (YYYY-MM-DD HH:MM) UTC TZ for starting the lease '
-                 '(default: now)',
+                 '(default: current time on the server)',
             default=self.default_start
         )
         parser.add_argument(
             '--end-date',
             dest='end',
             help='Time (YYYY-MM-DD HH:MM) UTC TZ for ending the lease '
-                 '(default: 24h later)',
+                 '(default: 24h from now)',
             default=self.default_end
         )
         parser.add_argument(
@@ -177,18 +177,25 @@ class CreateLease(command.CreateCommand):
         if parsed_args.name:
             params['name'] = parsed_args.name
         if not isinstance(parsed_args.start, datetime.datetime):
-            try:
-                parsed_args.start = datetime.datetime.strptime(
-                    parsed_args.start, '%Y-%m-%d %H:%M')
-            except ValueError:
-                raise exception.IncorrectLease
+            if parsed_args.start != 'now':
+                try:
+                    parsed_args.start = datetime.datetime.strptime(
+                        parsed_args.start, '%Y-%m-%d %H:%M')
+                except ValueError:
+                    raise exception.IncorrectLease
         if not isinstance(parsed_args.end, datetime.datetime):
             try:
                 parsed_args.end = datetime.datetime.strptime(
                     parsed_args.end, '%Y-%m-%d %H:%M')
             except ValueError:
                 raise exception.IncorrectLease
-        if parsed_args.start > parsed_args.end:
+
+        if parsed_args.start == 'now':
+            start = datetime.datetime.utcnow()
+        else:
+            start = parsed_args.start
+
+        if start > parsed_args.end:
             raise exception.IncorrectLease
 
         if parsed_args.before_end:
@@ -197,14 +204,17 @@ class CreateLease(command.CreateCommand):
                     parsed_args.before_end, '%Y-%m-%d %H:%M')
             except ValueError:
                 raise exception.IncorrectLease
-            if (parsed_args.before_end < parsed_args.start
+            if (parsed_args.before_end < start
                     or parsed_args.end < parsed_args.before_end):
                 raise exception.IncorrectLease
             params['before_end'] = datetime.datetime.strftime(
                 parsed_args.before_end, '%Y-%m-%d %H:%M')
 
-        params['start'] = datetime.datetime.strftime(parsed_args.start,
-                                                     '%Y-%m-%d %H:%M')
+        if parsed_args.start == 'now':
+            params['start'] = parsed_args.start
+        else:
+            params['start'] = datetime.datetime.strftime(parsed_args.start,
+                                                         '%Y-%m-%d %H:%M')
         params['end'] = datetime.datetime.strftime(parsed_args.end,
                                                    '%Y-%m-%d %H:%M')
 
